#
# spec file for package trytond
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2015-2021 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define majorver 5.0
%define base_name tryton
Name:           trytond
Version:        %{majorver}.36
Release:        lp152.2.28.1
Summary:        An Enterprise Resource Planning (ERP) system
License:        GPL-3.0-or-later
Group:          Productivity/Office/Management
URL:            https://www.tryton.org/
Source0:        http://downloads.tryton.org/%{majorver}/%{name}-%{version}.tar.gz
Source1:        tryton-server.README.openSUSE
Source2:        trytond.conf.example
Source3:        %{name}.conf
Source4:        %{name}_log.conf
Source5:        http://downloads.tryton.org/%{majorver}/%{name}-%{version}.tar.gz.asc
Source6:        https://keybase.io/cedrickrier/pgp_keys.asc?fingerprint=7C5A4360F6DF81ABA91FD54D6FF50AFE03489130#/%{name}.keyring
Source20:       %{name}.service
Patch0:         fix_werkzeug.patch
Patch1:         revert_werkzeug_setup.patch
Patch2:         fix_werkzeug_2.x.patch
Patch3:         Update_changed_fields.diff
BuildRequires:  fdupes
BuildRequires:  python3-Werkzeug
BuildRequires:  python3-bcrypt
BuildRequires:  python3-lxml >= 2.0
BuildRequires:  python3-psycopg2
BuildRequires:  python3-pydot3
BuildRequires:  python3-python-sql
BuildRequires:  python3-setuptools
BuildRequires:  python3-wrapt

Requires:       html2text
Requires:       libreoffice-pyuno
Requires:       postgresql-server
Requires:       python3-Genshi
Requires:       python3-Levenshtein
Requires:       python3-Sphinx
Requires:       python3-Werkzeug
Requires:       python3-bcrypt
Requires:       python3-dateutil
Requires:       python3-lxml
Requires:       python3-mock
Requires:       python3-passlib >= 1.7.0
Requires:       python3-polib
Requires:       python3-psycopg2 >= 2.5.4
Requires:       python3-python-sql >= 0.4
Requires:       python3-relatorio >= 0.7.0
Requires:       python3-simpleeval
Requires:       python3-wrapt
Requires:       unoconv
Requires(pre):  %{_sbindir}/groupadd
Requires(pre):  %{_sbindir}/useradd
BuildArch:      noarch
%{?systemd_ordering}

%description
This package contains the server of the Tryton application platform,
the latter of which is a three-tier high-level general purpose
application platform written in Python, using Postgresql as the
database engine. Tryton provides modularity, scalability and
security.

%prep
%setup -q
cp %{SOURCE1} .
cp %{SOURCE2} .
%patch0 -p1
%patch1 -p1
%patch3 -p1

#Werkzeug2 is not compatible with Werkzeug 1.x, so we need a conditional patch
echo 0%{?suse_version}
%if 0%{?suse_version} >= 1550
%patch2 -p1
%endif

%build
%python3_build

%install
%python3_install --prefix=%{_prefix} --root=%{buildroot}

# only for systemd
mkdir -p %{buildroot}%{_sysconfdir}/%{base_name}
install -p -m 640 %{SOURCE3} %{buildroot}%{_sysconfdir}/%{base_name}/%{name}.conf
install -p -m 640 %{SOURCE4} %{buildroot}%{_sysconfdir}/%{base_name}/%{name}_log.conf

mkdir -p %{buildroot}%{_unitdir}
install -p -m 644 %{SOURCE20} %{buildroot}%{_unitdir}/%{name}.service

mkdir -p %{buildroot}%{_localstatedir}/{lib,log}/%{base_name}
%fdupes -s %{buildroot}

%pre
getent group tryton > /dev/null || %{_sbindir}/groupadd -r tryton || :
getent passwd tryton > /dev/null || %{_sbindir}/useradd -r -g tryton \
       -d %{_localstatedir}/lib/tryton -s /sbin/nologin \
	-c 'Tryton ERP' tryton || :
%service_add_pre trytond.service

%post
%service_add_post trytond.service

%preun
%service_del_preun trytond.service

%postun
%service_del_postun trytond.service

%files
%license LICENSE
%doc README tryton-server.README.openSUSE trytond.conf.example doc/*
%{python3_sitelib}/*
%dir %{_sysconfdir}/%{base_name}
%{_bindir}/%{name}
%{_bindir}/%{name}-admin
%{_bindir}/%{name}-cron
%{_bindir}/%{name}-worker
%{_unitdir}/%{name}.service
%attr(640,root,tryton) %config(noreplace)%{_sysconfdir}/%{base_name}/%{name}.conf
%attr(640,root,tryton) %config(noreplace)%{_sysconfdir}/%{base_name}/%{name}_log.conf
%attr(755,tryton,tryton) %dir %{_localstatedir}/lib/%{base_name}
%attr(755,tryton,tryton) %dir %{_localstatedir}/log/%{base_name}

%changelog
* Wed Oct 27 2021 Axel Braun <axel.braun@gmx.de>
- Update_changed_fields.diff added to force update of XML files
* Tue Jul 27 2021 Axel Braun <axel.braun@gmx.de>
- fix_werkzeug_2.x.patch added for python-Werkzeug 2.x compatibility
* Fri Jun 18 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.36 - Bugfix Release
* Sun May 16 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.35 - Bugfix Release
* Tue Apr 27 2021 Axel Braun <axel.braun@gmx.de>
- Parameter for webdav server added to trytond.conf
* Sun Apr  4 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.34 - Bugfix Release
* Sat Feb 27 2021 Andreas Stieger <andreas.stieger@gmx.de>
- add upstream signing key and validate source signature
* Tue Feb 16 2021 Axel Braun <axel.braun@gmx.de>
- python3-passlib added
* Mon Feb 15 2021 Axel Braun <axel.braun@gmx.de>
- fix_werkzeug.patch adjusted
* Fri Feb 12 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.33 - Security fix for https://bugs.tryton.org/issue10068
* Tue Feb  2 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.32 - Bugfix Release
* Sun Jan 24 2021 Axel Braun <axel.braun@gmx.de>
- Adaption to new systemd and python macros
* Fri Jan  1 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.31 - Bugfix Release
* Fri Dec  4 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.30 - Bugfix Release
* Wed Nov 11 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.29 - Bugfix Release
* Tue Oct 20 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.28 - Bugfix Release
* Sat Oct  3 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.27 - Bugfix Release
* Mon Aug 24 2020 Axel Braun <axel.braun@gmx.de>
- changed trytond.conf to listen to all interfaces
* Thu Aug 20 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.25 - Bugfix Release
* Tue Jul 21 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.24 - Bugfix Release
  * readme renamed (SUSE -> openSUSE)
* Tue Jun  9 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.23 - Bugfix Release
* Tue Mar 10 2020 Axel Braun <axel.braun@gmx.de>
- version 5.0.19
  revert_werkzeug_setup.patch added to remove dependency on werkzeug < 1.0
* Wed Mar  4 2020 Ondřej Súkup <mimi.vx@gmail.com>
- add fix_werkzeug.patch to fix boo#1164970
- remove implicit _service (not needed anymore for download)
- spec-clean to meet openSUSE packaging standards
* Sun Feb  2 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.18 - Bugfix Release
* Fri Jan 10 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.17 - Bugfix Release
* Tue Dec  3 2019 Axel Braun <axel.braun@gmx.de>
- Version 5.0.16 - Bugfix Release
* Thu Nov 21 2019 Axel Braun <axel.braun@gmx.de>
- version 5.0.15 (upgrade to GNU Health 3.6.x)
  get_login_trytond-46.patch removed
* Mon Nov 11 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.22 - Bugfix Release
* Thu Oct 24 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.21 - Bugfix Release
  home directory of tryton user corrected (boo #1155685)
* Sun Sep 15 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.20 - Bugfix Release
* Tue Aug 20 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.19 - Bugfix Release
* Fri Aug  2 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.18 - Bugfix Release
* Fri Jul 12 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.17 - Bugfix Release
* Fri May 17 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.15 - Bugfix Release
* Wed Feb 20 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.13 - Bugfix Release
* Fri Feb  1 2019 Axel Braun <axel.braun@gmx.de>
- removed record-rpm option in %%install, as this fails to build in Factory
* Sun Jan 27 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.12 - Bugfix Release
* Mon Jan  7 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.11 - cummulated changes:
  * trytond_get_login.patch removed (series 4.2)
  * get_login_trytond-46.patch added for 4.6 series
  * trytond42_psql10.diff removed (not needed for 4.6)
* Mon Dec 10 2018 Axel Braun <axel.braun@gmx.de>
- Version 4.2.17 - Bugfix Release
* Tue Nov 13 2018 Axel Braun <axel.braun@gmx.de>
- Version 4.2.16 - Bugfix Release
* Wed Aug 22 2018 axel.braun@gmx.de
- Version 4.2.15 - Bugfix Release (boo#1107771)
* Sat Aug  4 2018 axel.braun@gmx.de
- Version 4.2.14 - Bugfix Release
* Thu Jul 19 2018 axel.braun@gmx.de
- trytond42_psql10.diff applied for postgres10 compatibility
  Kudos to mbehrle@m9s.biz!
* Wed Jul 11 2018 axel.braun@gmx.de
- Version 4.2.13 - Bugfix Release
* Tue Jun 12 2018 axel.braun@gmx.de
- boo#1096706 set postgres96 using update-alternatives (openQA failure)
* Mon Jun 11 2018 axel.braun@gmx.de
- Version 4.2.12 - Bugfix Release
  boo#1096706 requirement for postgres96 fixed
  copyright to log file and readme added
  Specfile cleaned up
* Sat May 12 2018 axel.braun@gmx.de
- Version 4.2.11 - Bugfix Release
* Fri Apr 27 2018 axel.braun@gmx.de
- requires postgres96, otherwise trytond-admin fails (Leap 15)
* Fri Mar  2 2018 axel.braun@gmx.de
- Version 4.2.10 - Bugfix Release
* Sat Feb 17 2018 axel.braun@gmx.de
- user_login.patch replaced by trytond_get_login.patch
  see boo#1078111
* Fri Jan  5 2018 axel.braun@gmx.de
- Version 4.2.9 - Bugfix Release
* Tue Dec  5 2017 axel.braun@gmx.de
- Version 4.2.8 - Bugfix Release
* Thu Nov  9 2017 axel.braun@gmx.de
- Version 4.2.7 - Bugfix Release
* Thu Sep 14 2017 axel.braun@gmx.de
- Documentation updated
* Thu Aug 10 2017 axel.braun@gmx.de
- Version 4.2.6
  bugfix release
  typo in trytond.conf removed
* Mon Jul 10 2017 axel.braun@gmx.de
- default setting for database access in trytond.conf
* Mon Jul  3 2017 axel.braun@gmx.de
- Version 4.2.5
* Tue Jun 20 2017 axel.braun@gmx.de
- Patch for user login user_login.patch from GNU Health 3.20 applied
  trytond_server.diff removed as not needed anymore
* Tue Jun  6 2017 axel.braun@gmx.de
- Version 4.2.4
* Mon Apr  3 2017 axel.braun@gmx.de
- Version 4.2.3
* Fri Mar 10 2017 axel.braun@gmx.de
- Version 4.2.2
* Fri Jan  6 2017 axel.braun@gmx.de
- Version 4.2.1
* Mon Nov 28 2016 axel.braun@gmx.de 
- Tryton Release 4.2
* Wed Aug 24 2016 axel.braun@gmx.de
- Update description
- Add missing %%service_add_pre and convert open-coded other
  three scriptlets to %%service_*.
* Tue Jul  5 2016 axel.braun@gmx.de
- version 4.0.2
* Mon May  2 2016 axel.braun@gmx.de 
- Tryton Release 4.0
* Mon Mar 28 2016 axel.braun@gmx.de
- patch for security vulnerability applied, see
  https://savannah.gnu.org/forum/forum.php?forum_id=8482
* Sun Jan 17 2016 axel.braun@gmx.de
- Installation of sao (webfrontend) documented
* Mon Oct 19 2015 axel.braun@gmx.de 
- Tryton Release 3.8
* Wed May 27 2015 axel.braun@gmx.de
- version 3.6.1
  * clean up of specfile
* Wed Apr 15 2015 axel.braun@gmx.de 
- Tryton Release 3.6
* Sat Feb 28 2015 axel.braun@gmx.de
- sample file for confirguration added (trytond.conf.example)
  tryton-server.README.SUSE updated
* Fri Nov 14 2014 axel.braun@gmx.de
- systemd startup file corrected, sample file for log config added
* Tue Nov  4 2014 axel.braun@gmx.de
- added trytond.conf
* Sun Nov  2 2014 axel.braun@gmx.de
- version 3.4
* Wed Oct 23 2013 axel.braun@gmx.de
- new branch 3.0, added python-sql
* Tue Oct 22 2013 axel.braun@gmx.de
- Tryton 3.0, spec file adapted
* Sat Jun 22 2013 axel.braun@gmx.de
- new spec with regard to systemd
- setup of user tryton if not existing
* Sun Mar 29 2009 axel.braun@gmx.de
- packaged tryton version 1.0.3 using the buildservice spec file wizard
